Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(953)

Unified Diff: Source/core/html/imports/HTMLImportChild.cpp

Issue 1032293002: Oilpan: dispose an HTMLImportsController on document detach/removal. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: No need to call dispose() when destructing HTMLImportsController Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/html/imports/HTMLImportChild.h ('k') | Source/core/html/imports/HTMLImportLoader.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/imports/HTMLImportChild.cpp
diff --git a/Source/core/html/imports/HTMLImportChild.cpp b/Source/core/html/imports/HTMLImportChild.cpp
index 9abd0c0b1ea170f5dfcb3d5c66616e8dbb87aa8b..b03804c26a3e0844f569a295ad2c178627ba3fb4 100644
--- a/Source/core/html/imports/HTMLImportChild.cpp
+++ b/Source/core/html/imports/HTMLImportChild.cpp
@@ -56,7 +56,7 @@ HTMLImportChild::HTMLImportChild(const KURL& url, HTMLImportLoader* loader, Sync
HTMLImportChild::~HTMLImportChild()
{
#if !ENABLE(OILPAN)
// importDestroyed() should be called before the destruction.
ASSERT(!m_loader);
if (m_client)
@@ -100,8 +100,7 @@ void HTMLImportChild::didFinishUpgradingCustomElements()
m_customElementMicrotaskStep.clear();
}
-#if !ENABLE(OILPAN)
-void HTMLImportChild::importDestroyed()
+void HTMLImportChild::dispose()
{
if (parent())
parent()->removeChild(this);
@@ -110,7 +109,6 @@ void HTMLImportChild::importDestroyed()
m_loader->removeImport(this);
m_loader = nullptr;
}
-#endif
Document* HTMLImportChild::document() const
{
@@ -161,7 +159,7 @@ bool HTMLImportChild::isDone() const
HTMLImportLoader* HTMLImportChild::loader() const
{
// This should never be called after importDestroyed.
ASSERT(m_loader);
return m_loader;
}
@@ -56,7 +56,7 @@ HTMLImportChild::HTMLImportChild(const KURL& url, HTMLImportLoader* loader, Sync
{
#if !ENABLE(OILPAN)
- // importDestroyed() should be called before the destruction.
+ // dispose() should be called before the destruction.
ASSERT(!m_loader);
if (m_client)
@@ -161,7 +159,7 @@ bool HTMLImportChild::isDone() const
HTMLImportLoader* HTMLImportChild::loader() const
{
- // This should never be called after importDestroyed.
+ // This should never be called after dispose().
ASSERT(m_loader);
return m_loader;
« no previous file with comments | « Source/core/html/imports/HTMLImportChild.h ('k') | Source/core/html/imports/HTMLImportLoader.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698